@@ -5,12 +5,10 @@ import os
 import sys
 import time
 import signal
-import shutil
 import subprocess
-from liblo import ServerThread, Address, make_method, Message
-from PyQt5.QtCore import (pyqtSignal, QObject, QTimer, QProcess, QSettings,
+from PyQt5.QtCore import (QObject, QTimer, QProcess, QSettings,
                           QLocale, QTranslator, QFile)
-from PyQt5.QtWidgets import (QApplication, QDialog, QFileDialog, QMessageBox,
+from PyQt5.QtWidgets import (QApplication, QDialog, QFileDialog,
                              QMainWindow)
 from PyQt5.QtXml import QDomDocument
 
@@ -37,7 +35,7 @@ def signalHandler(sig, frame):
         else:
             #sys.exit()
             app.quit()
-        
+
 
 
 def ifDebug(string):
@@ -70,7 +68,7 @@ class ProxyDialog(QMainWindow):
         QMainWindow.__init__(self)
         self.ui = ui_proxy_gui.Ui_MainWindow()
         self.ui.setupUi(self)
-        
+
         self.server = server
         self.proxy = proxy
 
@@ -79,7 +77,7 @@ class ProxyDialog(QMainWindow):
         self.fields_allow_start = False
         self.process_is_running = False
 
-        
+
         self.ui.toolButtonBrowse.clicked.connect(self.browseFile)
 
         self.ui.lineEditExecutable.textEdited.connect(
@@ -88,14 +86,14 @@ class ProxyDialog(QMainWindow):
             self.lineEditArgumentsChanged)
         self.ui.lineEditConfigFile.textChanged.connect(
             self.lineEditConfigFileChanged)
-        
+
         self.ui.comboSaveSig.addItem(_translate('proxy', 'None'), 0)
         self.ui.comboSaveSig.addItem('SIGUSR1', int(signal.SIGUSR1))
         self.ui.comboSaveSig.addItem('SIGUSR2', int(signal.SIGUSR2))
-        self.ui.comboSaveSig.addItem('SIGINT',  int(signal.SIGINT))
+        self.ui.comboSaveSig.addItem('SIGINT', int(signal.SIGINT))
         self.ui.comboSaveSig.activated.connect(self.comboSaveSigChanged)
         self.ui.comboSaveSig.setCurrentIndex(0)
-        
+
         self.ui.comboNoSave.addItem(
             _translate('proxy', "0 - Ignore missing save"))
         self.ui.comboNoSave.addItem(
@@ -105,13 +103,13 @@ class ProxyDialog(QMainWindow):
         self.ui.comboNoSave.setCurrentIndex(2)
         self.ui.comboNoSave.activated.connect(self.comboNoSaveChanged)
         self.ui.labelNoSaveLevel.setToolTip(self.ui.comboNoSave.toolTip())
-        
+
         self.ui.comboStopSig.addItem('SIGTERM', int(signal.SIGTERM))
         self.ui.comboStopSig.addItem('SIGINT', int(signal.SIGINT))
         self.ui.comboStopSig.addItem('SIGHUP', int(signal.SIGHUP))
         self.ui.comboStopSig.activated.connect(self.comboStopSigChanged)
         self.ui.comboStopSig.setCurrentIndex(0)
-        
+
         self.ui.comboSaveSig.currentTextChanged.connect(self.allowSaveTest)
         self.ui.toolButtonTestSave.clicked.connect(self.testSave)
         self.ui.toolButtonTestSave.setEnabled(False)
@@ -134,7 +132,7 @@ class ProxyDialog(QMainWindow):
         self.fields_allow_start = True
         if not self.ui.lineEditExecutable.text():
             self.fields_allow_start = False
-        
+
         if ray.shellLineToArgs(self.ui.lineEditArguments.text()) is None:
             self.fields_allow_start = False
 
@@ -145,13 +143,13 @@ class ProxyDialog(QMainWindow):
         self.ui.lineEditExecutable.setText(proxy.executable)
         self.ui.lineEditConfigFile.setText(proxy.config_file)
         self.ui.lineEditArguments.setText(proxy.arguments_line)
-                
+
         save_index = self.ui.comboSaveSig.findData(proxy.save_signal)
         self.ui.comboSaveSig.setCurrentIndex(save_index)
 
         self.ui.comboNoSave.setCurrentIndex(proxy.no_save_level)
         self.ui.comboNoSave.setEnabled(not bool(proxy.save_signal))
-        
+
         stop_index = self.ui.comboStopSig.findData(proxy.stop_signal)
         self.ui.comboStopSig.setCurrentIndex(stop_index)
 
@@ -208,40 +206,40 @@ class ProxyDialog(QMainWindow):
     def lineEditConfigFileChanged(self, text):
         if text and not self.ui.lineEditArguments.text():
             self.ui.lineEditArguments.setText('"$CONFIG_FILE"')
-        elif (not text 
+        elif (not text
               and self.ui.lineEditArguments.text() == '"$CONFIG_FILE"'):
             self.ui.lineEditArguments.setText('')
 
     def comboSaveSigChanged(self, index):
         self.ui.comboNoSave.setEnabled(bool(index == 0))
-        
+
         save_signal = 0
-        
+
         if index == 1:
             save_signal = signal.SIGUSR1
         elif index == 2:
             save_signal = signal.SIGUSR2
         elif index == 3:
             save_signal = signal.SIGINT
-            
+
         save_signal = int(save_signal)
         self.proxy.setSaveSignal(save_signal)
-    
+
     def comboStopSigChanged(self, index):
         stop_signal = signal.SIGTERM
-        
+
         if index == 1:
             stop_signal = signal.SIGINT
         elif index == 2:
             stop_signal = signal.SIGTERM
-            
+
         stop_signal = int(stop_signal)
         self.proxy.setStopSignal(stop_signal)
-    
+
     def comboNoSaveChanged(self, index):
         self.proxy.no_save_level = index
         self.proxy.sendNoSaveLevel()
-    
+
     def allowSaveTest(self, text=None):
         if text is None:
             text = self.ui.comboSaveSig.currentText()
@@ -309,11 +307,11 @@ class ProxyDialog(QMainWindow):
         server.sendToDaemon('/nsm/client/gui_is_hidden')
         settings.setValue(
             'ProxyGui%s/geometry' %
-            self.proxy.full_client_id,
+            self.proxy.client_id,
             self.saveGeometry())
         settings.setValue(
             'ProxyGui%s/WindowState' %
-            self.proxy.full_client_id, self.saveState())
+            self.proxy.client_id, self.saveState())
         settings.sync()
 
         if self.fields_allow_start:
@@ -328,16 +326,16 @@ class ProxyDialog(QMainWindow):
     def showEvent(self, event):
         self.server.sendToDaemon('/nsm/client/gui_is_shown')
 
-        if settings.value('ProxyGui%s/geometry' % self.proxy.full_client_id):
+        if settings.value('ProxyGui%s/geometry' % self.proxy.client_id):
             self.restoreGeometry(
                 settings.value(
                     'ProxyGui%s/geometry' %
-                    self.proxy.full_client_id))
-        if settings.value('ProxyGui%s/WindowState' % self.proxy.full_client_id):
+                    self.proxy.client_id))
+        if settings.value('ProxyGui%s/WindowState' % self.proxy.client_id):
             self.restoreState(
                 settings.value(
                     'ProxyGui%s/WindowState' %
-                    self.proxy.full_client_id))
+                    self.proxy.client_id))
 
         self.updateValuesFromProxyFile()
 
@@ -357,7 +355,8 @@ class Proxy(QObject):
         self.project_path = ""
         self.path = ""
         self.session_name = ""
-        self.full_client_id = ""
+        self.client_id = ""
+        self.jack_client_name = ""
 
         self.executable = executable
         self.arguments = []
@@ -367,12 +366,12 @@ class Proxy(QObject):
         self.no_save_level = 2
         self.stop_signal = int(signal.SIGTERM)
         self.label = ""
-        
+
         self.wait_window = False
 
         self._config_file_used = False
         self._wait_for_stop = False
-        
+
         self.timer_save = QTimer()
         self.timer_save.setSingleShot(True)
         self.timer_save.setInterval(300)
@@ -406,14 +405,14 @@ class Proxy(QObject):
 
     def waitForStop(self):
         self._wait_for_stop = True
-    
+
     def setSaveSignal(self, int_signal):
         self.save_signal = int_signal
         self.sendNoSaveLevel()
-        
+
     def setStopSignal(self, int_signal):
         self.stop_signal = int_signal
-    
+
     def readFile(self):
         self.is_launchable = False
         try:
@@ -450,15 +449,15 @@ class Proxy(QObject):
 
         if save_signal.isdigit():
             self.save_signal = int(save_signal)
-        
+
         if no_save_level.isdigit():
             self.no_save_level = int(no_save_level)
         else:
             self.no_save_level = 2
-        
+
         versions = [file_version, '0.7.1']
         versions.sort()
-        
+
         if file_version != versions[0]:
             # something was wrong in old version,
             # save signal was saved as stop signal too.
@@ -513,7 +512,7 @@ class Proxy(QObject):
         file.close()
 
         self.readFile()
-    
+
     def updateValues(self, executable, config_file, arguments_line,
                      save_signal, no_save_level, stop_signal, wait_window):
         self.executable = executable
@@ -523,7 +522,7 @@ class Proxy(QObject):
         self.no_save_level = no_save_level
         self.stop_signal = stop_signal
         self.wait_window = wait_window
-    
+
     def saveProxyFile(self):
         self.saveFile(
             self.executable,
@@ -533,18 +532,18 @@ class Proxy(QObject):
             self.no_save_level,
             self.stop_signal,
             self.wait_window)
-    
+
     def updateAndSave(self, executable, config_file, arguments_line,
                       save_signal, no_save_level, stop_signal, wait_window):
-        self.updateValues(executable, config_file, arguments_line, 
+        self.updateValues(executable, config_file, arguments_line,
                           save_signal, no_save_level,
                           stop_signal, wait_window)
         self.saveProxyFile()
-    
+
     def processFinished(self, exit_code):
         if self._wait_for_stop:
             app.quit()
-            
+
         if self.is_finishable:
             if not proxy_dialog.isVisible():
                 app.quit()
@@ -552,12 +551,12 @@ class Proxy(QObject):
             duration = time.time() - self.process_start_time
             proxy_dialog.processTerminateShortly(duration)
             # proxy_dialog.show()
-    
+
     def checkWindow(self):
         self.timer_window_n += 1
 
         if self.timer_window_n > 600:
-            # 600 x 50ms = 30s max until ray-proxy 
+            # 600 x 50ms = 30s max until ray-proxy
             # replyOpen to Session Manager
             self.checkWindowEnded()
             return
@@ -612,7 +611,7 @@ class Proxy(QObject):
                 except BaseException:
                     self.checkWindowEnded()
                     return
-                    
+
                 for line in proc_contents.split('\n'):
                     if line.startswith('PPid:'):
                         ppid_str = line.rpartition('\t')[2]
@@ -622,7 +621,7 @@ class Proxy(QObject):
                 else:
                     self.checkWindowEnded()
                     return
-                
+
             if ppid == parent_pid:
                 # a window appears with a pid child of this ray-proxy,
                 # replyOpen
@@ -633,10 +632,11 @@ class Proxy(QObject):
         self.timer_window.stop()
         server.openReply()
 
-    def initialize(self, project_path, session_name, full_client_id):
+    def initialize(self, project_path, session_name, jack_client_name):
         self.project_path = project_path
         self.session_name = session_name
-        self.full_client_id = full_client_id
+        self.client_id = project_path.rpartition('.')[2]
+        self.jack_client_name = jack_client_name
 
         server.sendGuiState(False)
 
@@ -645,8 +645,8 @@ class Proxy(QObject):
 
         os.chdir(project_path)
 
-        #proxy_dialog.setWindowTitle(self.full_client_id)
-        
+        proxy_dialog.setWindowTitle("Ray Proxy - %s" % self.client_id)
+
         self.path = os.path.join(project_path, "ray-proxy.xml")
         self.readFile()
 
@@ -658,32 +658,43 @@ class Proxy(QObject):
             return
 
         self.startProcess()
-    
+
     def sendNoSaveLevel(self):
         if ':no-save-level:' in server.getServerCapabilities():
             nsl = self.no_save_level
             if self.save_signal:
                 nsl = 0
             server.sendToDaemon('/nsm/client/no_save_level', nsl)
-    
+
     def startProcess(self):
-        os.environ['NSM_CLIENT_ID'] = self.full_client_id
+        os.environ['NSM_CLIENT_ID'] = self.jack_client_name
+        os.environ['RAY_CLIENT_ID'] = self.client_id
         os.environ['RAY_SESSION_NAME'] = self.session_name
 
         # enable environment vars in config_file
         config_file = os.path.expandvars(self.config_file)
         os.environ['CONFIG_FILE'] = config_file
 
+        # because that is not done by python itself
+        os.environ['PWD'] = os.getcwd()
+
         # Useful for launching NSM compatible clients with specifics arguments
+        nsm_url = os.getenv('NSM_URL')
+        ray_port_str = nsm_url.rpartition(':')[2]
+        if ray_port_str.endswith('/'):
+            ray_port_str = ray_port_str[:-1]
+        if ray_port_str.isdigit():
+            os.environ['RAY_CONTROL_PORT'] = ray_port_str
+
         os.unsetenv('NSM_URL')
 
         arguments_line = os.path.expandvars(self.arguments_line)
         arguments = ray.shellLineToArgs(arguments_line)
-        
+
         self._config_file_used = bool(config_file
                                       and config_file in arguments)
         self.sendNoSaveLevel()
-        
+
         self.process.start(self.executable, arguments)
         self.timer_open.start()
 
@@ -732,9 +743,9 @@ class Proxy(QObject):
             proxy_dialog.close()
 
 
-class ProxyFile(object):
+class ProxyFile:
     def __init__(self, project_path, executable=''):
-        
+
 
         self.executable = executable
         self.arguments_line = ''
@@ -744,10 +755,10 @@ class ProxyFile(object):
         self.stop_signal = int(signal.SIGTERM)
         self.wait_window = False
 
-        
 
-    
-    
+
+
+
 
 if __name__ == '__main__':
     NSM_URL = os.getenv('NSM_URL')
@@ -776,14 +787,14 @@ if __name__ == '__main__':
     app.setOrganizationName("RaySession")
     app.setQuitOnLastWindowClosed(False)
     settings = QSettings()
-    
+
     signal.signal(signal.SIGINT, signalHandler)
     signal.signal(signal.SIGTERM, signalHandler)
 
     # Translation process
     locale = QLocale.system().name()
     appTranslator = QTranslator()
-    
+
     if appTranslator.load(
         "%s/locale/raysession_%s" %
         (os.path.dirname(
@@ -800,15 +811,15 @@ if __name__ == '__main__':
     timer.start()
 
     signaler = nsm_client.NSMSignaler()
-    
+
     server = nsm_client.NSMThread('ray-proxy', signaler,
                                   daemon_address, debug)
     server.start()
-    
+
     proxy = Proxy(executable)
     proxy_dialog = ProxyDialog()
 
-    
+
     server.announce('Ray Proxy', ':optional-gui:warning-no-save:', 'ray-proxy')
 
     app.exec()
