@@ -17,6 +17,7 @@ class Signaler(QObject):
     snapshots_found = pyqtSignal(list)
     reply_auto_snapshot = pyqtSignal(bool)
     server_progress = pyqtSignal(float)
+    client_progress = pyqtSignal(str, float)
     server_status_changed = pyqtSignal(int)
 
     daemon_url_request = pyqtSignal(int, str)
@@ -35,5 +36,7 @@ class Signaler(QObject):
     favorite_added = pyqtSignal(str, str, bool)
     favorite_removed = pyqtSignal(str, bool)
 
+    canvas_callback = pyqtSignal(int, int, int, str)
+
     def __init__(self):
         QObject.__init__(self)
